@@ -39,7 +39,8 @@ from ..build_storage import BuildStorage, Build
 from ..drive_spool import DriveSpool
 from .action import Actions as BuilderActions
 from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
-                                    TableVariable, WRITEABLE)
+                                    TableVariable, WRITEABLE,
+                                    ReadonlyTableVariable, HumanReadable)
 from functools import wraps
 
 _ = lambda x: x
@@ -1146,6 +1147,22 @@ class VariableClBuilderBranchData(TableVariable):
         raise VariableError(_("Repository %s not found") % value)
 
 
+class VariableClBuilderBriefBranchData(ReadonlyTableVariable):
+    """
+    Вывод синхронизируемые репозиториев для brief
+    """
+    source = ["cl_builder_branch_rep",
+              "cl_builder_branch_name"]
+
+    def init(self):
+        self.help = _("set references for repository (REPOSITORY:REF)")
+        self.label = _("Repositories references")
+
+    def get(self, hr=HumanReadable.No):
+        return list(reversed(self.Get('cl_builder_branch_data',
+                                      humanreadable=hr)))
+
+
 class VariableClBuilderBranchRep(ReadonlyVariable):
     """
     Список доступных репозиториев
@@ -1270,7 +1287,7 @@ class VariableClBuilderSquashExclude(ReadonlyVariable):
         builder_path = self.Get('cl_builder_path')
         keep_tree = self.GetBool('cl_builder_keep_tree_set')
         excludes = ["", "metadata"]
-        important = [".git", "distfiles", "packages", "eclass", "metadata",
+        important = ["distfiles", "packages", "eclass", "metadata",
                      "profiles", "layout.conf"]
         exclude_dirs = ["profiles/templates/deprecated"]
 
@@ -1652,6 +1669,7 @@ class VariableClBuilderBinhostStableSet(
                 return dv.Get('update.cl_update_binhost_stable_opt_set')
         return self.Get('update.cl_update_binhost_stable_opt_set')
 
+
 class VariableClBuilderBinhostScanSet(Variable):
     """
     Сканировать или нет зеркала (переменная переключается во время действия)
